Index: chrome/test/ppapi/ppapi_test.cc |
diff --git a/chrome/test/ppapi/ppapi_test.cc b/chrome/test/ppapi/ppapi_test.cc |
index 5da65af23cb562124c7a2e47b8508c7dabc4cc1e..b6d1a5a0c695db824d97bd23f1d92fe12e522157 100644 |
--- a/chrome/test/ppapi/ppapi_test.cc |
+++ b/chrome/test/ppapi/ppapi_test.cc |
@@ -263,14 +263,19 @@ void PPAPITest::SetUpCommandLine(CommandLine* command_line) { |
PPAPITestBase::SetUpCommandLine(command_line); |
// Append the switch to register the pepper plugin. |
// library name = <out dir>/<test_name>.<library_extension> |
// MIME type = application/x-ppapi-<test_name> |
FilePath plugin_dir; |
EXPECT_TRUE(PathService::Get(base::DIR_MODULE, &plugin_dir)); |
FilePath plugin_lib = plugin_dir.Append(library_name); |
EXPECT_TRUE(file_util::PathExists(plugin_lib)); |
FilePath::StringType pepper_plugin = plugin_lib.value(); |
+ pepper_plugin.append(FILE_PATH_LITERAL("#PPAPI Tests")); |
+ pepper_plugin.append(FILE_PATH_LITERAL("#")); // No description. |
+ pepper_plugin.append(FILE_PATH_LITERAL("#1.2.3")); |
pepper_plugin.append(FILE_PATH_LITERAL(";application/x-ppapi-tests")); |
command_line->AppendSwitchNative(switches::kRegisterPepperPlugins, |
pepper_plugin); |
@@ -263,14 +263,19 @@ void PPAPITest::SetUpCommandLine(CommandLine* command_line) { |
PPAPITestBase::SetUpCommandLine(command_line); |
// Append the switch to register the pepper plugin. |
- // library name = <out dir>/<test_name>.<library_extension> |
- // MIME type = application/x-ppapi-<test_name> |
+ // library path = <out dir>/<test_name>.<library_extension> |
+ // library name = "PPAPI Tests" |
+ // version = "1.2.3" |
+ // MIME type = "application/x-ppapi-tests" |
FilePath plugin_dir; |
EXPECT_TRUE(PathService::Get(base::DIR_MODULE, &plugin_dir)); |